@@ -1,7 +1,7 @@
 # -------------------------------------------------------------------------------------
 # MKDoc::XML::Tagger
 # -------------------------------------------------------------------------------------
-# Author : Jean-Michel Hiver <jhiver@mkdoc.com>.
+# Author : Jean-Michel Hiver.
 # Copyright : (c) MKDoc Holdings Ltd, 2003
 #
 # This module adds markup to an existing XML file / variable by matching expression.
@@ -362,7 +362,7 @@ For this same reason MKDoc::XML::Tagger does not support namespaces.
 
 Copyright 2003 - MKDoc Holdings Ltd.
 
-Author: Jean-Michel Hiver <jhiver@mkdoc.com>
+Author: Jean-Michel Hiver
 
 This module is free software and is distributed under the same license as Perl
 itself. Use it at your own risk.
